@@ -1,7 +1,9 @@
 from dataclasses import dataclass
-from typing import Optional
+from typing import Any, Dict, Optional
+
 from darwin.path_utils import construct_full_path
 
+
 @dataclass(frozen=True, eq=True)
 class DatasetItem:
     id: int
@@ -20,7 +22,7 @@ class DatasetItem:
         return construct_full_path(self.path, self.filename)
 
 
-def parse_dataset_item(raw) -> DatasetItem:
+def parse_dataset_item(raw: Dict[str, Any]) -> DatasetItem:
     return DatasetItem(
         raw["id"],
         raw["filename"],
